#!/bin/sh

# enable Kismet client console mode
export TERMINFO=/usr/share/terminfo

# enable colors in kismet console
export TERM=screen

# "qpewlan0" is the default first value (-> it should be there,
# if you have at least one wlan network definied)
USERSCHEME=qpewlan1

# set here your config for gpsd (if you have one)
# if you also have qpegps installed this script will take the
# config for gpsd from there (if you set it here to "")
#GPSOPT="-p /dev/ttyS0 -s 4800"
#GPSOPT="-p /home/zaurus/temp/123 -s 4800" # to dump the raw data to gpsd
GPSOPT=""

# the default port kismet_server listens. This value is primary
# read from /opt/QtPalmtop/etc/kismet/kismet_ui.conf, and the value
# defined here is just taken if the read value is empty
KISMET_SERVER_PORT="2501"

# no changes should be done from here down
LOGFILE=/tmp/k.sh.startup
GPSOPT_DEFAULT="-p /dev/ttyS0 -s 4800"
VERSION=$( sed -n "/^Package: kismet/,/^$/p" /usr/lib/ipkg/status | grep "^Version" | cut -d\  -f2 )
#NO_DEBUG_SERVER=""
NO_DEBUG_SERVER="--silent"

# startup info
echo "+++ START - `date "+%Y/%m/%d %H:%M:%S"` --------------------" > $LOGFILE 2>&1
echo "Starting kismet $VERSION"
# check for gpsd on system
GPSD=""
GPSCONFIG="local"
GPSSTART=""
if [ -x /usr/bin/gpsd ] ; then
  GPSD="/usr/bin/gpsd"
fi
if [ -x /opt/QtPalmtop/bin/gpsd ] ; then
  GPSD="/opt/QtPalmtop/bin/gpsd"
fi
# handle gpsd, if we found a binary
if [ ! -z "$GPSD" ] ; then
  # searching for a running gpsd
  if [ "$(ps axf | grep [gG]psd)" ] ; then
    echo "found GPSd -- not starting it"
    echo "--- found GPSd -- not starting it" >> $LOGFILE 2>&1
  else
    # taking gpsd startup parameter from qpegps, if _everything_ is available
    if [ -f /home/zaurus/Settings/qpegps.conf ] && [ -x /opt/QtPalmtop/bin/gpsd ] ; then
      # and just, if no user options are set
      if [ -z "$GPSOPT" ] ; then
        GPSOPT=$( sed -n "/^\[gps\]/,/^\[/p" /home/zaurus/Settings/qpegps.conf | grep "^gpsd" | cut -d= -f 2 )
        GPSCONFIG="qpegps"
        if [ -z "$GPSOPT" ] ; then
          # unable to parse the config
          GPSOPT="$GPSOPT_DEFAULT"
          GPSCONFIG="no qpegps"
        fi
      fi
    else
      # something is not right with qpegps, so take defaults
      GPSOPT="$GPSOPT_DEFAULT"
    fi
    if [ -z "$GPSOPT" ] ; then
      echo "No gpsd config specified - not starting gpsd"
      echo "--- No gpsd config specified - not starting gpsd" >> $LOGFILE 2>&1
    else
      echo "Starting GPS ($GPSD) with $GPSOPT ($GPSCONFIG config)"
      echo "--- $GPSD $GPSOPT ($GPSCONFIG config)" >> $LOGFILE 2>&1
      $GPSD $GPSOPT >> $LOGFILE 2>&1
      GPSSTART="done"
    fi
  fi
else
  echo "No gpsd executable found"
  echo "--- No gpsd executable found" >> $LOGFILE 2>&1
fi

# activating wlan card
echo "Starting WLAN Card"
echo "--- cardctl scheme CardResume" >> $LOGFILE 2>&1
cardctl scheme CardResume >> $LOGFILE 2>&1
#echo "--- cardctl scheme $USERSCHEME" >> $LOGFILE 2>&1
#cardctl scheme $USERSCHEME >> $LOGFILE 2>&1 &
#PID=$!
#sleep 5 
#sudo kill $PID
#sudo killall dhcpcd
#sudo ifconfig wlan0 up
echo "Disabling suspend.."
qcop QPE/System 'setScreenSaverIntervals(int,int,int)' 0 0 0
#sudo iwconfig wlan0 mode Monitor
#sudo killall wpa_supplicant
# starting kismet server (the real sniffer)
echo "Starting Server"
# brr - thats qpe...
# it seems not to be possible to save the 4775 mod for kismet_server
# when you install with the graphical installer
echo "--- chmod kismet_server" >> $LOGFILE 2>&1
sudo chmod 4755 /opt/QtPalmtop/bin/kismet_server >> $LOGFILE 2>&1
echo "--- kismet_server" >> $LOGFILE 2>&1
( kismet_server $NO_DEBUG_SERVER & ) #>>$LOGFILE 2>&1 & ) >> $LOGFILE 2>&1
# wait for server to finish startup and to listen for clients
echo -n "Waiting for server "
CONNECTED="false"
PORT=$(grep "^host" /opt/QtPalmtop/etc/kismet/kismet_ui.conf 2>/dev/null | awk -F: '{printf $2}')
if [ -z $PORT ] ; then
  # the default value
  PORT="KISMET_SERVER_PORT"
fi
# wait for 10 seconds (no "seq" in default...)
for i in $(echo "1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20") ; do
  echo "--- kismet_client (Port $PORT): try $i" >> $LOGFILE 2>&1
  echo -n "."
  # is the server listening?
  PORT_OPEN=$(netstat -an 2>/dev/null | grep ^tcp | grep :$PORT | wc -l)
  if [ $PORT_OPEN -gt 0 ] ; then
    echo "found: \"$(sudo netstat -anp 2>/dev/null | grep ^tcp | grep :$PORT)\"" >> $LOGFILE 2>&1
    CONNECTED="true"
    break;
  fi
  # delay 0.5 seconds
  usleep 500000
done
if [ "$CONNECTED" = "false" ] ; then
  echo ""
  echo "Unable to find Server on localhost:$PORT - exiting"
  echo "--- Unable to find Server on localhost:$PORT - exiting" >> $LOGFILE 2>&1
else
  echo ""
  echo "Starting Userinterface"
  echo "--- kismet_client starting" >> $LOGFILE 2>&1
  kismet_client
  echo ""
  echo ""
  # to let the user know - we are dying
#  wavplay /opt/QtPalmtop/share/kismet/wav/shutdown.wav >> $LOGFILE 2>&1
fi
echo -n "Stopping WLAN Sniffer "
echo "--- kill kismet_server" >> $LOGFILE 2>&1
KISMET_PIDS=$(echo $(ps ax | grep [kK]ismet_server | awk '{printf$1"\n"}' | sort -r))
for i in $KISMET_PIDS ; do
  echo "--- kill kismet_server $i - ($KISMET_PIDS)" >> $LOGFILE 2>&1
  kill $i >> $LOGFILE 2>&1
done
KILLED="false"
for i in $(echo "1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20") ; do
  echo "--- kismet kill: try $i" >> $LOGFILE 2>&1
  echo -n "."
  KISMET_HERE=$(ps axf | grep "[kK]ismet_server" | wc -l)
  if [ $KISMET_HERE -lt 1 ] ; then
    KILLED="true"
    break;
  fi
  usleep 500000
done
if [ "$KILLED" = "false" ] ; then
  echo "--- kill -9 kismet_server ($KISMET_PIDS)" >> $LOGFILE 2>&1
  sudo kill -9 $KISMET_PIDS >> $LOGFILE 2>&1
fi
echo ""
echo "Stopping WLAN Card"
echo "--- cardctl scheme CardSuspend" >> $LOGFILE 2>&1
cardctl scheme CardSuspend >> $LOGFILE 2>&1
echo "Enabling suspend"
qcop QPE/System 'setScreenSaverIntervals(int,int,int)' -1 -1 -1
if [ ! -z "$GPSSTART" ] ; then
  echo "Stopping gpsd (started in script)"
  echo "--- stopping gpsd" >> $LOGFILE 2>&1
  killall gpsd
fi
echo "+++ END - `date "+%Y/%m/%d %H:%M:%S"` --------------------" >> $LOGFILE 2>&1

